NanoCap Guide & Documentation

Guide & Documentation
M. Robinson
2012-2014

`NanoCap` provides both libraries and a standalone application for the construction of capped nanotubes of arbitrary chirality and fullerenes of any radius. Structures are generated by constructing a set of optimal dual graph topologies which are subsequently optimised using a carbon interatomic potential. Combining this approach with a GUI featuring 3D rendering capabilities allows for the rapid inspection of physically sensible structures which can be used as input for molecular simulation.

The `NanoCap` source and builds for different platforms can be found at:

`http://nanocap.sourceforge.net/download`

The `NanoCap` documentation is outlined in the following sections.

- 1 Installation
  - 1.1 Requirements
  - 1.2 Installing from source
- 2 Generating a Single Structure
  - 2.1 Fullerenes
  - 2.2 Nanotubes
  - 2.3 Capped Nanotubes
- 3 Generating Multiple Structures
  - 3.1 Structure Search
- 4 Force Fields
  - 4.1 Dual Lattice Force Fields
  - 4.2 Carbon Lattice Force Fields
- 5 Optimisation
- 6 Storing, Loading and Exporting
  - 6.1 The Local NanoCap Database
  - 6.2 The Online NanoCap Database
  - 6.3 Exporting
- 7 Rendering
  - 7.1 Schlegel View
- 8 Scientific Publications
- 9 Code
  - 9.1 Algorithm Flow Diagram
  - 9.2 Non-GUI Class Structure
  - 9.3 GUI Class Structure
- 10 Examples
  - 10.1 Nanotube Construction
  - 10.2 Fullerenes
  - 10.3 Capped Nanotube Construction
  - 10.4 Database Operations
  - 10.5 Visualisation